RLBot

Loading RLBotGUI...

If you get stuck on this message, you're probably having an issue with javascript or connecting to the backend. If you've disabled javascript in your browser, you may need to re-enable it. If you're not sure, you can collect some information and ask for help on Discord. We'll want to know:

- What's in the console output? (black window with text)
- Are there any errors in the javascript console? Press F12 and look in the 'console' area.